@@ -72,7 +72,7 @@ typedef struct {
 	CDDrivePriv *priv;
 } CDDrive;
 
-#define SIZE_TO_TIME(size) (int) (((size / 1024 / 1024) - 1) * 48 / 7)
+#define SIZE_TO_TIME(size) (size > 0 ? (int) (((size / 1024 / 1024) - 1) * 48 / 7): 0)
 
 /* Returns a list of CDDrive structs */
 GList *scan_for_cdroms (gboolean recorder_only, gboolean add_image);
