@@ -40,7 +40,8 @@ typedef enum {
 	CDRECORDER_DUMMY_WRITE			= 1 << 2,
 	CDRECORDER_DISC_AT_ONCE			= 1 << 3,
 	CDRECORDER_DEBUG			= 1 << 4,
-	CDRECORDER_OVERBURN			= 1 << 5
+	CDRECORDER_OVERBURN			= 1 << 5,
+	CDRECORDER_BURNPROOF			= 1 << 6
 } CDRecorderWriteFlags;
 
 #define CD_TYPE_RECORDER            (cd_recorder_get_type ())
@@ -53,6 +54,18 @@ typedef struct CDRecorder                CDRecorder;
 typedef struct CDRecorderClass           CDRecorderClass;
 typedef struct CDRecorderPrivate         CDRecorderPrivate;
 
+typedef enum {
+	PREPARING_WRITE,
+	WRITING,
+	FIXATING,
+	BLANKING
+} CDRecorderActions;
+
+typedef enum {
+	MEDIA_CD,
+	MEDIA_DVD,
+} CDRecorderMedia;
+
 struct CDRecorder {
 	GObject parent;
 	CDRecorderPrivate *priv;
@@ -64,7 +77,8 @@ struct CDRecorderClass {
 	void (*progress_changed)	(CDRecorder *cdrecorder,
 					 gdouble fraction);
 	void (*action_changed)		(CDRecorder *cdrecorder,
-					 gint index);
+					 CDRecorderActions action,
+					 CDRecorderMedia media);
 	void (*animation_changed)	(CDRecorder *cdrecorder,
 					 gboolean spinning);
 	void (*insert_cd_request)	(CDRecorder *cdrecorder,
@@ -76,8 +90,6 @@ struct CDRecorderClass {
 GType		cd_recorder_get_type		(void);
 CDRecorder     *cd_recorder_new			(void);
 
-GList	       *cd_recorder_list_actions	(CDRecorder *cdrecorder);
-
 int		cd_recorder_write_tracks	(CDRecorder *cdrecorder,
 						 CDDrive *drive,
 						 GList *tracks,
