@@ -56,6 +56,51 @@ static int cancel = CANCEL_NONE;
 /* For the image spinning */
 static GList *image_list;
 
+static GtkWidget *
+ncb_hig_dialog (GtkMessageType type, char *title, char *reason,
+		GtkWindow *parent)
+{
+	GtkWidget *error_dialog;
+	char *title_esc, *reason_esc;
+
+	if (reason == NULL)
+		g_warning (" called with reason == NULL");
+
+	title_esc = g_markup_escape_text (title, -1);
+	reason_esc = g_markup_escape_text (reason, -1);
+
+	error_dialog =
+		gtk_message_dialog_new (parent,
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				type,
+				GTK_BUTTONS_NONE,
+				"<b>%s</b>\n%s", title_esc, reason_esc);
+	gtk_window_set_title (GTK_WINDOW (error_dialog), title_esc);
+	g_free (title_esc);
+	g_free (reason_esc);
+
+	gtk_container_set_border_width (GTK_CONTAINER (error_dialog), 5);
+	gtk_dialog_set_default_response (GTK_DIALOG (error_dialog),
+			GTK_RESPONSE_OK);
+	gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (error_dialog)->label), TRUE);
+	gtk_window_set_modal (GTK_WINDOW (error_dialog), TRUE);
+
+	return error_dialog;
+}
+
+static void
+ncb_hig_show_error_dialog (char *title, char *reason, GtkWindow *parent)
+{
+	GtkWidget *dialog;
+
+	dialog = ncb_hig_dialog (GTK_MESSAGE_ERROR, title, reason, parent);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			GTK_STOCK_OK, GTK_RESPONSE_OK);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+}
+
 /* Originally eel_make_valid_utf8 */
 static char *
 ncb_make_valid_utf8 (const char *name)
@@ -225,12 +270,47 @@ animation_changed_cb (CDRecorder *cdrecorder, gboolean spinning, gpointer data)
 }
 
 static void
-action_changed_cb (CDRecorder *cdrecorder, gint index, gpointer data)
+action_changed_cb (CDRecorder *cdrecorder, CDRecorderActions action,
+		CDRecorderMedia media)
 {
-	GList *list;
+	const char *text;
 
-	list = cd_recorder_list_actions (cdrecorder);
-	cd_progress_set_text ((const char *)g_list_nth (list, index)->data);
+	text = NULL;
+
+	switch (action) {
+	case PREPARING_WRITE:
+		if (media == MEDIA_CD) {
+			text = N_("Preparing to write CD");
+		} else {
+			text = N_("Preparing to write DVD");
+		}
+		break;
+	case WRITING:
+		if (media == MEDIA_CD) {
+			text = N_("Writing CD");
+		} else {
+			text = N_("Writing DVD");
+		}
+		break;
+	case FIXATING:
+		if (media == MEDIA_CD) {
+			text = N_("Fixating CD");
+		} else {
+			text = N_("Fixating DVD");
+		}
+		break;
+	case BLANKING:
+		if (media == MEDIA_CD) {
+			text = N_("Erasing CD");
+		} else {
+			text = N_("Erasing DVD");
+		}
+		break;
+	default:
+		g_warning ("Unhandled action in action_changed_cb");
+	}
+
+	cd_progress_set_text (text);
 }
 
 static void
@@ -266,11 +346,12 @@ insert_cd_request_cb (CDRecorder *cdrecorder,
 	}
 
 	parent = glade_xml_get_widget (xml, "cdr_dialog");
-	dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
-			GTK_DIALOG_MODAL,
-			GTK_MESSAGE_INFO,
-			GTK_BUTTONS_OK_CANCEL,
-			"%s", _(msg));
+	dialog = ncb_hig_dialog (GTK_MESSAGE_INFO,
+			_(msg), _(title), GTK_WINDOW (parent));
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+			GTK_STOCK_OK, GTK_RESPONSE_OK,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 			GTK_RESPONSE_OK);
 	gtk_window_set_title (GTK_WINDOW (dialog), _(title));
@@ -289,7 +370,7 @@ details_clicked (GtkButton *button, gpointer data)
 	GtkWidget *dialog, *label, *text, *scrolled_window;
 	GtkTextBuffer *buffer;
 
-	dialog = gtk_dialog_new_with_buttons (_("CD writing error details"),
+	dialog = gtk_dialog_new_with_buttons (_("Disc writing error details"),
 					      cd_progress_get_window (),
 					      GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
@@ -333,16 +414,17 @@ static void
 show_error_message (CDRecorder *cdrecorder)
 {
 	GtkWidget *button, *dialog;
+	char *msg;
+
+	msg = cd_recorder_get_error_message (cdrecorder) ?
+		g_strdup_printf (_("There was an error writing to the CD:\n%s"), cd_recorder_get_error_message (cdrecorder))
+		: g_strdup (_("There was an error writing to the CD"));
+	dialog = ncb_hig_dialog (GTK_MESSAGE_ERROR, _("Error writing to CD"),
+			msg, cd_progress_get_window ());
+	g_free (msg);
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			GTK_STOCK_OK, GTK_RESPONSE_OK);
 
-	dialog = gtk_message_dialog_new (cd_progress_get_window (),
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_OK,
-					 cd_recorder_get_error_message (cdrecorder) ?
-					 _("There was an error writing to the CD:\n%s") : _("There was an error writing to the CD"),
-					 cd_recorder_get_error_message (cdrecorder));
-	gtk_window_set_title (GTK_WINDOW (dialog),
-			      _("Error writing to CD"));
 	button = gtk_button_new_with_mnemonic (_("_Details"));
 	gtk_widget_show (button);
 	gtk_box_pack_end (GTK_BOX (GTK_DIALOG (dialog)->action_area),
@@ -414,13 +496,13 @@ overwrite_existing_file (GtkWindow *filesel, const char *filename)
 {
 	GtkWidget *dialog;
 	gint ret;
+	char *msg;
+
+	msg = g_strdup_printf (_("A file named \"%s\" already exists.\nDo you want to overwrite it?"),
+			filename);
+	dialog = ncb_hig_dialog (GTK_MESSAGE_QUESTION, _("_Overwrite"),
+			msg, filesel);
 
-	dialog = gtk_message_dialog_new (filesel,
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_QUESTION,
-					 GTK_BUTTONS_NONE,
-					 _("A file named \"%s\" already exists.\nDo you want to overwrite it?"),
-					 filename);
 	/* Add Cancel button */
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
 			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
@@ -439,25 +521,6 @@ overwrite_existing_file (GtkWindow *filesel, const char *filename)
 	return (ret == GTK_RESPONSE_YES);
 }
 
-static void
-display_error_dialog (GtkWindow *win, const gchar *msg)
-{
-	GtkWidget *error_dlg;
-	
-	g_return_if_fail (msg != NULL);
-
-	error_dlg = gtk_message_dialog_new (win ? win : NULL,
-					    0,
-					    GTK_MESSAGE_ERROR,
-					    GTK_BUTTONS_OK,
-					    msg);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (error_dlg), GTK_RESPONSE_OK);
-	gtk_window_set_resizable (GTK_WINDOW (error_dlg), FALSE);
-	gtk_dialog_run (GTK_DIALOG (error_dlg));
-	gtk_widget_destroy (error_dlg);
-}
-
 static char *
 select_iso_filename (void)
 {
@@ -493,7 +556,7 @@ select_iso_filename (void)
 }
 
 static int
-burn_cd (const CDDrive *rec, const char *source_iso, const char *label, gboolean eject_cd, int speed, gboolean dummy, gboolean debug, gboolean overburn)
+burn_cd (const CDDrive *rec, const char *source_iso, const char *label, gboolean eject_cd, int speed, gboolean dummy, gboolean debug, gboolean overburn, gboolean burnproof)
 {
 	CDRecorderWriteFlags flags;
 	GList *tracks;
@@ -517,7 +580,11 @@ burn_cd (const CDDrive *rec, const char *source_iso, const char *label, gboolean
 			 */
 			if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 				if (access (filename, W_OK) == -1) {
-					display_error_dialog (NULL, _("Don't have permissions to overwrite file."));
+					char *msg;
+
+					msg = g_strdup_printf (_("You do not have permissions to overwrite that file (%s)."), filename);
+					ncb_hig_show_error_dialog (_("File image creation failed"), msg, NULL);
+					g_free (msg);
 					g_free (filename);
 					return RESULT_ERROR;
 				}
@@ -526,9 +593,13 @@ burn_cd (const CDDrive *rec, const char *source_iso, const char *label, gboolean
 				dir_name = g_path_get_dirname (filename);
 
 				if (access (dir_name, W_OK) == -1) {
-					display_error_dialog (NULL, _("Don't have permissions to create file."));
+					char *msg;
+
+					msg = g_strdup_printf (_("You do not have permissions to create that file (%s)."), filename);
+					ncb_hig_show_error_dialog (_("File image creation failed"), msg, NULL);
 					g_free (filename);
 					g_free (dir_name);
+					g_free (msg);
 					return RESULT_ERROR;
 				}
 				g_free (dir_name);
@@ -633,6 +704,9 @@ burn_cd (const CDDrive *rec, const char *source_iso, const char *label, gboolean
 		if (overburn) {
 			flags |= CDRECORDER_OVERBURN;
 		}
+		if (burnproof) {
+			flags |= CDRECORDER_BURNPROOF;
+		}
 
 		res = cd_recorder_write_tracks (cdrecorder, (CDDrive *)rec,
 				tracks, speed, flags);
@@ -842,14 +916,15 @@ ask_cancel (void)
 	GtkWidget *warning_dialog;
 	int res;
 
-	warning_dialog = gtk_message_dialog_new (cd_progress_get_window (),
-						 GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_WARNING,
-						 GTK_BUTTONS_YES_NO,
-						 _("Are you sure you want to cancel the CD write operation?\n"
-						 "Some CD writers may require that you restart the machine to get it working again."));
-	gtk_window_set_title (GTK_WINDOW (warning_dialog),
-			      _("Are you sure you want to cancel?"));
+	warning_dialog = ncb_hig_dialog (GTK_MESSAGE_WARNING,
+			_("Cancel write"),
+			_("Are you sure you want to cancel the disc write operation?\n"
+			"Some optical media drives may require that you restart the machine to get it working again."),
+			cd_progress_get_window ());
+	gtk_dialog_add_buttons (GTK_DIALOG (warning_dialog),
+			_("Continue"), GTK_RESPONSE_NO,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_YES,
+			NULL);
 	res = gtk_dialog_run (GTK_DIALOG (warning_dialog));
 	gtk_widget_destroy (warning_dialog);
 
@@ -900,7 +975,8 @@ help_activate (GtkWindow *parent)
 		char *msg;
 
 		msg = g_strdup_printf (_("There was a problem displaying the help contents: %s."), err->message);
-		display_error_dialog (parent, msg);
+		ncb_hig_show_error_dialog (_("Cannot display help"),
+				msg, parent);
 		g_error_free (err);
 		g_free (msg);
 	}
@@ -991,7 +1067,7 @@ main (int argc, char *argv[])
 	GtkWidget *cancel_button, *dummy_check, *option_menu, *item;
 	const char *label;
 	int res, speed, i;
-	gboolean eject, reuse, dummy, debug, overburn;
+	gboolean eject, reuse, dummy, debug, overburn, burnproof;
 	GnomeVFSURI *uri;
 	GnomeVFSFileSize size;
 	char *source_iso, *disc_name;
@@ -1013,13 +1089,12 @@ main (int argc, char *argv[])
 	gnome_vfs_init ();
 
 	if (argc > 2) {
-		dialog = gtk_message_dialog_new (NULL,
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_OK,
-						 _("Too many parameters to nautilus-cd-burner"));
-		gtk_window_set_title (GTK_WINDOW (dialog),
-				      _("Too many parameters"));
+		dialog = ncb_hig_dialog (GTK_MESSAGE_ERROR,
+				_("Too many parameters"),
+				_("Too many parameters were passed to the application."),
+				NULL);
+		gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_OK,
+				GTK_RESPONSE_OK);
 		res = gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		return 1;
@@ -1035,14 +1110,15 @@ main (int argc, char *argv[])
 
 	if (source_iso != NULL) {
 		if (!verify_iso (source_iso, &disc_name)) {
-			dialog = gtk_message_dialog_new (NULL,
-							 GTK_DIALOG_MODAL,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_OK,
-							 _("The file '%s' is not a valid CD image."),
-							 source_iso);
-			gtk_window_set_title (GTK_WINDOW (dialog),
-					      _("Not a valid CD image"));
+			char *msg;
+
+			msg = g_strdup_printf
+				(_("The file '%s' is not a valid CD image."),
+				 source_iso);
+			dialog = ncb_hig_dialog (GTK_MESSAGE_ERROR,
+					_("Not a valid CD image"),
+					msg, NULL);
+			g_free (msg);
 			res = gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 			return 1;
@@ -1054,15 +1130,12 @@ main (int argc, char *argv[])
 		size = estimate_size ("burn:///");
 
 		if (size == 0) {
-			dialog = gtk_message_dialog_new (NULL,
-							 GTK_DIALOG_MODAL,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_NONE,
-							 _("You need to copy the files you want to write to CD to the CD Creator window. Would you like to open it now?"));
-			gtk_dialog_add_buttons (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, _("Open CD Creator"), GTK_RESPONSE_YES, NULL);
+			dialog = ncb_hig_dialog (GTK_MESSAGE_ERROR,
+					_("No files selected"),
+					_("You need to copy the files you want to write to disc to the CD/DVD Creator window. Would you like to open it now?"),
+					NULL);
+			gtk_dialog_add_buttons (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, _("Open CD/DVD Creator"), GTK_RESPONSE_YES, NULL);
 			gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
-			gtk_window_set_title (GTK_WINDOW (dialog),
-					      _("No files selected"));
 			res = gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 			if (res == GTK_RESPONSE_YES) {
@@ -1075,7 +1148,11 @@ main (int argc, char *argv[])
 		}
 	}
 
-	xml = glade_xml_new (DATADIR "/cdburn.glade", NULL, NULL);
+	if (g_file_test ("cdburn.glade", G_FILE_TEST_EXISTS) != FALSE) {
+		xml = glade_xml_new (DATADIR "/cdburn.glade", NULL, NULL);
+	} else {
+		xml = glade_xml_new (DATADIR "/cdburn.glade", NULL, NULL);
+	}
 	dialog = glade_xml_get_widget (xml, "cdr_dialog");
 
 	init_dialog (xml, dialog, size, disc_name, source_iso != NULL);
@@ -1091,6 +1168,7 @@ main (int argc, char *argv[])
 	gc = gconf_client_get_default ();
 	debug = gconf_client_get_bool (gc, "/apps/nautilus-cd-burner/debug", NULL);
 	overburn = gconf_client_get_bool (gc, "/apps/nautilus-cd-burner/overburn", NULL);
+	burnproof = gconf_client_get_bool (gc, "/apps/nautilus-cd-burner/burnproof", NULL);
 	g_object_unref (G_OBJECT (gc));
 
 	if (debug == FALSE) {
@@ -1141,7 +1219,7 @@ main (int argc, char *argv[])
 		gconf_client_set_int (gc, "/apps/nautilus-cd-burner/default_speed", speed, NULL);
 		g_object_unref (G_OBJECT (gc));
 
-		res = burn_cd (rec, source_iso, label, eject, speed, dummy, debug, overburn);
+		res = burn_cd (rec, source_iso, label, eject, speed, dummy, debug, overburn, burnproof);
 
 		reuse_check = glade_xml_get_widget (xml, "reuse_check");
 		reuse = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (reuse_check));
